## Deployment of startR

This section contains the information on system requirements and the steps to set up such environment. Note that if you are at BSC, you do not need to follow the complete list of deployment steps here since all dependencies are already installed for you to use.

This documentation seperates into two sections. The first one is for [retrieve data](inst/doc/deployment.md#deployment-steps-for-retrieving-data-locally). If you also want to [process data on a distributed HPC](inst/doc/deployment.md#deployment-steps-for-processing-data-on-distributed-hpcs), more installations are needed.

### Deployment steps for retrieving data

Install the followings:

1. R (>= 2.14.1)
2. startR package
You can choose either of the following ways:
- Install the latest published version on CRAN. Run the following lines in your R session:

```r
install.packages('startR')
library(startR)
```

- Install the latest stable version from the GitLab repository:
```r
devtools::install_git('https://earth.bsc.es/gitlab/es/startR.git')
```

Installing `startR` will trigger the installation of the other required packages. 
- `bigmemory` package will be installed with `startR` installation.
- `easyNCDF` package will be installed if `Start()` function is used to load NetCDF files (which is only file format supported by now).

3. netCDF-4 
This is required if you plan to retrieve NetCDF files (which is only file format supported by now):
    - zlib (>= 1.2.3) and HDF5 (>= 1.8.0-beta1) are required by netCDF-4
    - Steps for installation of netCDF-4 are detailed in https://www.unidata.ucar.edu/software/netcdf/docs/getting_and_building_netcdf.html


4. s2dverification package (>= 2.8.4) and CDO (version 1.6.3 tested)
These are required if you plan to interpolate the data with CDO (either by using the `transform` parameter in `startR::Start`, or by using `s2dverification::CDORemap` in the workflow specified to `startR::Compute`).

5. A local or remote file system or THREDDS/OPeNDAP server providing the data to be retrieved from the workstation you run the code must be accessible. In BSC-ES, the data repository could be under `/esarchive/exp/` or `/esarchive/obs/` or`/esarchive/recon/`.


### Deployment steps for processing data on distributed HPCs

If you want not only to retrieve data locally but also to process the data on a distributed HPC (i.e., cluster of multi-processor/ multi-core nodes), the following settings are required.

1. All machines (your workstation, the HPC) must be UNIX-based, with the "hostname", "date", "touch" and "sed" commands available.

2. Install the following libraries on your workstation:
    - ssh
    - scp
    - rsync (>= 3.0.6)
    - EC-Flow (>= 4.9.0)

3. Set up passwordless, userless ssh access
    - at least from your workstation to the HPC login node
    - if possible, also from the HPC login node to your workstation

4. If you are using a separate EC-Flow host node to control your EC-Flow workflows (optional), install EC-Flow (>= 4.9.0) on the EC-Flow host node

5. Install the following libraries on the HPC login node:
    - ssh
    - scp
    - rsync (>= 3.0.6)
    - EC-Flow (>= 4.9.0), as a Linux Environment Module (optional)
    - Job scheduler (Slurm, PBS or LSF) to distribute the workload across HPC nodes

6. Make sure the following requirements are fulfilled by all HPC nodes:
    - netCDF-4 is installed, if loading and processing NetCDF files (the only supported format by now)
    - R (>= 2.14.1) is installed as a Linux Environment Module
    - The startR package is installed
    - If using CDO interpolation, the s2dverification package and CDO v1.6.3 are installed
    - any other R packages required by the `startR::Compute` workflow (e.g., the package including the used function) are installed
    - Any other Environment Modules used by the `startR::Compute` workflow are installed
    - A shared file system (with a unified access point) or THREDDS/OPeNDAP server is accessible across HPC nodes and HPC login node, where the necessary data can be uploaded from your workstation. 
    - A file system shared between your workstation and the HPC is also supported and advantageous. 
    - Use of a data transfer service between the workstation and the HPC is also supported under specific configurations.

### Other useful documentation
If you are a new startR users and have not read [**README**](https://earth.bsc.es/gitlab/es/startR/blob/master/README.md), you are recommended to read it first to get a general picture of startR. Then, you can follow the order to know more:
1. See [**Deployment**](inst/doc/deployment.md) for details on the setup if outside of BSC.
2. Follow [**Practical Guide**](inst/doc/practical_guide.md) with use cases step by step.
3. See [**Start**](inst/doc/start.md) to learn more applications of Start().
4. Find [**FAQs**](https://earth.bsc.es/gitlab/es/startR/wikis/FAQ) and [**Examples**](https://earth.bsc.es/gitlab/es/startR/wikis/Example) in GitLab wiki page.

